@@ -2,25 +2,25 @@
 pyeight.constants
 ~~~~~~~~~~~~~~~~~~~~
 Constants list
-Copyright (c) 2017-2021 John Mihalic <https://github.com/mezz64>
+Copyright (c) 2017-2022 John Mihalic <https://github.com/mezz64>
 Licensed under the MIT license.
 """
 
 MAJOR_VERSION = 0
-MINOR_VERSION = 1
-SUB_MINOR_VERSION = 9
+MINOR_VERSION = 2
+SUB_MINOR_VERSION = 0
 __version__ = '{}.{}.{}'.format(
     MAJOR_VERSION, MINOR_VERSION, SUB_MINOR_VERSION)
 
 API_URL = 'https://client-api.8slp.net/v1'
 
-DEFAULT_TIMEOUT = 60
+DEFAULT_TIMEOUT = 240
 
 DEFAULT_HEADERS = {
-    'content-type': "application/x-www-form-urlencoded",
+    'content-type': "application/json",
     'connection': "keep-alive",
-    'user-agent': "okhttp/3.6.0",
+    'user-agent': "okhttp/4.9.1",
     'accept-encoding': "gzip",
-    'accept': "*/*",
+    'accept': "application/json",
     'authority': "client-api.8slp.net",
     }
